==> fess-fess_tags_fess-7.0.1-r1373.tar.gz: fess-fess_tags_fess-7.0.1-r1373/fess-7.0.1/src/main/java/jp/sf/fess/db/bsbhv/pmbean/BsFavoriteUrlRankingPmb.java <==
/*
 * Copyright 2009-2012 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.db.bsbhv.pmbean;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;

import jp.sf.fess.db.allcommon.DBFluteConfig;
import jp.sf.fess.db.exbhv.FavoriteLogBhv;
import jp.sf.fess.db.exentity.customize.FavoriteUrlRanking;

import org.seasar.dbflute.cbean.SimplePagingBean;
import org.seasar.dbflute.cbean.coption.FromToOption;
import org.seasar.dbflute.exception.RequiredOptionNotFoundException;
import org.seasar.dbflute.jdbc.FetchBean;
import org.seasar.dbflute.jdbc.ParameterUtil;
import org.seasar.dbflute.jdbc.ParameterUtil.ShortCharHandlingMode;
import org.seasar.dbflute.outsidesql.typed.AutoPagingHandlingPmb;
import org.seasar.dbflute.outsidesql.typed.EntityHandlingPmb;
import org.seasar.dbflute.util.DfCollectionUtil;
import org.seasar.dbflute.util.DfTypeUtil;

/**
 * The base class for typed parameter-bean of FavoriteUrlRanking. <br />
 * This is related to "<span style="color: #AD4747">selectFavoriteUrlRanking</span>" on FavoriteLogBhv.
 * @author DBFlute(AutoGenerator)
 */
public class BsFavoriteUrlRankingPmb extends SimplePagingBean implements
        EntityHandlingPmb<FavoriteLogBhv, FavoriteUrlRanking>,
        AutoPagingHandlingPmb<FavoriteLogBhv, FavoriteUrlRanking>, FetchBean,
        Serializable {

    // ===================================================================================
    //                                                                          Definition
    //                                                                          ==========
    /** Serial version UID. (Default) */
    private static final long serialVersionUID = 1L;

    // ===================================================================================
    //                                                                           Attribute
    //                                                                           =========
    /** The parameter of fromCreatedTime:fromDate. */
    protected Date _fromCreatedTime;

    /** The parameter of toCreatedTime:toDate. */
    protected Date _toCreatedTime;

    // ===================================================================================
    //                                                                         Constructor
    //                                                                         ===========
    /**
     * Constructor for the typed parameter-bean of FavoriteUrlRanking. <br />
     * This is related to "<span style="color: #AD4747">selectFavoriteUrlRanking</span>" on FavoriteLogBhv.
     */
    public BsFavoriteUrlRankingPmb() {
        if (DBFluteConfig.getInstance().isPagingCountLater()) {
            enablePagingCountLater();
        }
    }

    // ===================================================================================
    //                                                                Typed Implementation
    //                                                                ====================
    /**
     * {@inheritDoc}
     */
    @Override
    public String getOutsideSqlPath() {
        return "selectFavoriteUrlRanking";
    }

    /**
     * Get the type of an entity for result. (implementation)
     * @return The type instance of an entity, customize entity. (NotNull)
     */
    @Override
    public Class<FavoriteUrlRanking> getEntityType() {
        return FavoriteUrlRanking.class;
    }

    // ===================================================================================
    //                                                                       Assist Helper
    //                                                                       =============
    protected String filterStringParameter(final String value) {
        if (isEmptyStringParameterAllowed()) {
            return value;
        }
        return convertEmptyToNull(value);
    }

    protected boolean isEmptyStringParameterAllowed() {
        return DBFluteConfig.getInstance().isEmptyStringParameterAllowed();
    }

    protected String convertEmptyToNull(final String value) {
        return ParameterUtil.convertEmptyToNull(value);
    }

    protected String handleShortChar(final String propertyName,
            final String value, final Integer size) {
        final ShortCharHandlingMode mode = getShortCharHandlingMode(
                propertyName, value, size);
        return ParameterUtil.handleShortChar(propertyName, value, size, mode);
    }

    protected ShortCharHandlingMode getShortCharHandlingMode(
            final String propertyName, final String value, final Integer size) {
        return ShortCharHandlingMode.NONE;
    }

    @SuppressWarnings("unchecked")
    protected <ELEMENT> ArrayList<ELEMENT> newArrayList(
            final ELEMENT... elements) {
        final Object obj = DfCollectionUtil.newArrayList(elements);
        return (ArrayList<ELEMENT>) obj; // to avoid the warning between JDK6 and JDK7
    }

    @SuppressWarnings("unchecked")
    protected <NUMBER extends Number> NUMBER toNumber(final Object obj,
            final Class<NUMBER> type) {
        return (NUMBER) DfTypeUtil.toNumber(obj, type);
    }

    protected Boolean toBoolean(final Object obj) {
        return DfTypeUtil.toBoolean(obj);
    }

    protected Date toUtilDate(final Date date) {
        return DfTypeUtil.toDate(date); // if sub class, re-create as pure date
    }

    protected String formatUtilDate(final Date date) {
        final String pattern = "yyyy-MM-dd";
        return DfTypeUtil.toString(date, pattern);
    }

    protected String formatByteArray(final byte[] bytes) {
        return "byte["
                + (bytes != null ? String.valueOf(bytes.length) : "null") + "]";
    }

    protected void assertFromToOptionValid(final String name,
            final FromToOption option) {
        if (option == null) {
            final String msg = "The from-to option is required!";
            throw new RequiredOptionNotFoundException(msg);
        }
    }

    // ===================================================================================
    //                                                                      Basic Override
    //                                                                      ==============
    /**
     * @return The display string of all parameters. (NotNull)
     */
    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        sb.append(DfTypeUtil.toClassTitle(this)).append(":");
        sb.append(xbuildColumnString());
        return sb.toString();
    }

    private String xbuildColumnString() {
        final String c = ", ";
        final StringBuilder sb = new StringBuilder();
        sb.append(c).append(formatUtilDate(_fromCreatedTime));
        sb.append(c).append(formatUtilDate(_toCreatedTime));
        if (sb.length() > 0) {
            sb.delete(0, c.length());
        }
        sb.insert(0, "{").append("}");
        return sb.toString();
    }

    // ===================================================================================
    //                                                                            Accessor
    //                                                                            ========
    /**
     * [get] fromCreatedTime:fromDate <br />
     * @return The value of fromCreatedTime. (Nullable, NotEmptyString(when String): if empty string, returns null)
     */
    public Date getFromCreatedTime() {
        return toUtilDate(_fromCreatedTime);
    }

    /**
     * [set as fromDate] fromCreatedTime:fromDate <br />
     * @param fromCreatedTime The value of fromCreatedTime. (NullAllowed)
     */
    public void setFromCreatedTime_FromDate(final Date fromCreatedTime) {
        _fromCreatedTime = new FromToOption().compareAsDate().filterFromDate(
                fromCreatedTime);
    }

    /**
     * [get] toCreatedTime:toDate <br />
     * @return The value of toCreatedTime. (Nullable, NotEmptyString(when String): if empty string, returns null)
     */
    public Date getToCreatedTime() {
        return toUtilDate(_toCreatedTime);
    }

    /**
     * [set as toDate] toCreatedTime:toDate <br />
     * @param toCreatedTime The value of toCreatedTime. (NullAllowed)
     */
    public void setToCreatedTime_ToDate(final Date toCreatedTime) {
        _toCreatedTime = new FromToOption().compareAsDate().filterToDate(
                toCreatedTime);
    }

}

==> fess-fess_tags_fess-8.0.0-r1596.tar.gz: fess-fess_tags_fess-8.0.0-r1596/fess-8.0.0/src/main/java/jp/sf/fess/db/bsbhv/pmbean/BsFavoriteUrlRankingPmb.java <==
/*
 * Copyright 2009-2013 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package jp.sf.fess.db.bsbhv.pmbean;

import java.util.ArrayList;
import java.util.Date;

import jp.sf.fess.db.allcommon.DBFluteConfig;
import jp.sf.fess.db.exbhv.FavoriteLogBhv;
import jp.sf.fess.db.exentity.customize.FavoriteUrlRanking;

import org.seasar.dbflute.cbean.SimplePagingBean;
import org.seasar.dbflute.cbean.coption.FromToOption;
import org.seasar.dbflute.exception.RequiredOptionNotFoundException;
import org.seasar.dbflute.jdbc.FetchBean;
import org.seasar.dbflute.jdbc.ParameterUtil;
import org.seasar.dbflute.jdbc.ParameterUtil.ShortCharHandlingMode;
import org.seasar.dbflute.outsidesql.typed.AutoPagingHandlingPmb;
import org.seasar.dbflute.outsidesql.typed.EntityHandlingPmb;
import org.seasar.dbflute.util.DfCollectionUtil;
import org.seasar.dbflute.util.DfTypeUtil;

/**
 * The base class for typed parameter-bean of FavoriteUrlRanking. <br />
 * This is related to "<span style="color: #AD4747">selectFavoriteUrlRanking</span>" on FavoriteLogBhv.
 * @author DBFlute(AutoGenerator)
 */
public class BsFavoriteUrlRankingPmb extends SimplePagingBean implements
        EntityHandlingPmb<FavoriteLogBhv, FavoriteUrlRanking>,
        AutoPagingHandlingPmb<FavoriteLogBhv, FavoriteUrlRanking>, FetchBean {

    // ===================================================================================
    //                                                                           Attribute
    //                                                                           =========
    /** The parameter of fromCreatedTime:fromDate. */
    protected Date _fromCreatedTime;

    /** The parameter of toCreatedTime:toDate. */
    protected Date _toCreatedTime;

    // ===================================================================================
    //                                                                         Constructor
    //                                                                         ===========
    /**
     * Constructor for the typed parameter-bean of FavoriteUrlRanking. <br />
     * This is related to "<span style="color: #AD4747">selectFavoriteUrlRanking</span>" on FavoriteLogBhv.
     */
    public BsFavoriteUrlRankingPmb() {
        if (DBFluteConfig.getInstance().isPagingCountLater()) {
            enablePagingCountLater();
        }
    }

    // ===================================================================================
    //                                                                Typed Implementation
    //                                                                ====================
    /**
     * {@inheritDoc}
     */
    @Override
    public String getOutsideSqlPath() {
        return "selectFavoriteUrlRanking";
    }

    /**
     * Get the type of an entity for result. (implementation)
     * @return The type instance of an entity, customize entity. (NotNull)
     */
    @Override
    public Class<FavoriteUrlRanking> getEntityType() {
        return FavoriteUrlRanking.class;
    }

    // ===================================================================================
    //                                                                       Assist Helper
    //                                                                       =============
    protected String filterStringParameter(final String value) {
        if (isEmptyStringParameterAllowed()) {
            return value;
        }
        return convertEmptyToNull(value);
    }

    protected boolean isEmptyStringParameterAllowed() {
        return DBFluteConfig.getInstance().isEmptyStringParameterAllowed();
    }

    protected String convertEmptyToNull(final String value) {
        return ParameterUtil.convertEmptyToNull(value);
    }

    protected String handleShortChar(final String propertyName,
            final String value, final Integer size) {
        final ShortCharHandlingMode mode = getShortCharHandlingMode(
                propertyName, value, size);
        return ParameterUtil.handleShortChar(propertyName, value, size, mode);
    }

    protected ShortCharHandlingMode getShortCharHandlingMode(
            final String propertyName, final String value, final Integer size) {
        return ShortCharHandlingMode.NONE;
    }

    @SuppressWarnings("unchecked")
    protected <ELEMENT> ArrayList<ELEMENT> newArrayList(
            final ELEMENT... elements) {
        final Object obj = DfCollectionUtil.newArrayList(elements);
        return (ArrayList<ELEMENT>) obj; // to avoid the warning between JDK6 and JDK7
    }

    @SuppressWarnings("unchecked")
    protected <NUMBER extends Number> NUMBER toNumber(final Object obj,
            final Class<NUMBER> type) {
        return (NUMBER) DfTypeUtil.toNumber(obj, type);
    }

    protected Boolean toBoolean(final Object obj) {
        return DfTypeUtil.toBoolean(obj);
    }

    protected Date toUtilDate(final Date date) {
        return DfTypeUtil.toDate(date); // if sub class, re-create as pure date
    }

    protected String formatUtilDate(final Date date) {
        final String pattern = "yyyy-MM-dd";
        return DfTypeUtil.toString(date, pattern);
    }

    protected String formatByteArray(final byte[] bytes) {
        return "byte["
                + (bytes != null ? String.valueOf(bytes.length) : "null") + "]";
    }

    protected void assertFromToOptionValid(final String name,
            final FromToOption option) {
        if (option == null) {
            final String msg = "The from-to option is required!";
            throw new RequiredOptionNotFoundException(msg);
        }
    }

    // ===================================================================================
    //                                                                      Basic Override
    //                                                                      ==============
    /**
     * @return The display string of all parameters. (NotNull)
     */
    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();
        sb.append(DfTypeUtil.toClassTitle(this)).append(":");
        sb.append(xbuildColumnString());
        return sb.toString();
    }

    private String xbuildColumnString() {
        final String c = ", ";
        final StringBuilder sb = new StringBuilder();
        sb.append(c).append(formatUtilDate(_fromCreatedTime));
        sb.append(c).append(formatUtilDate(_toCreatedTime));
        if (sb.length() > 0) {
            sb.delete(0, c.length());
        }
        sb.insert(0, "{").append("}");
        return sb.toString();
    }

    // ===================================================================================
    //                                                                            Accessor
    //                                                                            ========
    /**
     * [get] fromCreatedTime:fromDate <br />
     * @return The value of fromCreatedTime. (Nullable, NotEmptyString(when String): if empty string, returns null)
     */
    public Date getFromCreatedTime() {
        return toUtilDate(_fromCreatedTime);
    }

    /**
     * [set as fromDate] fromCreatedTime:fromDate <br />
     * @param fromCreatedTime The value of fromCreatedTime. (NullAllowed)
     */
    public void setFromCreatedTime_FromDate(final Date fromCreatedTime) {
        _fromCreatedTime = new FromToOption().compareAsDate().filterFromDate(
                fromCreatedTime);
    }

    /**
     * [get] toCreatedTime:toDate <br />
     * @return The value of toCreatedTime. (Nullable, NotEmptyString(when String): if empty string, returns null)
     */
    public Date getToCreatedTime() {
        return toUtilDate(_toCreatedTime);
    }

    /**
     * [set as toDate] toCreatedTime:toDate <br />
     * @param toCreatedTime The value of toCreatedTime. (NullAllowed)
     */
    public void setToCreatedTime_ToDate(final Date toCreatedTime) {
        _toCreatedTime = new FromToOption().compareAsDate().filterToDate(
                toCreatedTime);
    }

}
